@@ -4,10 +4,12 @@ from django.contrib import admin
 from django.utils.translation import ugettext_lazy as _
 
 from .actions import check_updated, clear_versions, clone
-from .forms import (FixedWidthColumnForm, CSVColumnForm, LeafletMarkerForm, ShapefileColumnForm,
+from .forms import (
+    FixedWidthColumnForm, CSVColumnForm, LeafletMarkerForm, ShapefileColumnForm,
     SpreadsheetColumnForm, SourceSpreadsheetForm, SourceCSVForm, SourceFixedWidthForm,
     SourceShapeForm, SimpleSourceColumnForm)
-from .models import (CSVColumn, SimpleSourceColumn, FixedWidthColumn, SourceDirect, LeafletMarker,
+from .models import (
+    CSVColumn, SimpleSourceColumn, FixedWidthColumn, SourceDirect, LeafletMarker,
     ShapefileColumn, SourceCSV, SourceDataVersion, SourceFixedWidth, SourceShape,
     SourceSpreadsheet, SourceSimple, SpreadsheetColumn)
 
@@ -47,8 +49,8 @@ class SimpleSourceColumnInline(SourceColumnInline):
 
 class SourceDataVersionInline(admin.TabularInline):
     model = SourceDataVersion
-    fields = ('active', 'datetime', 'timestamp', 'truncated_checksum', 'metadata', 'ready')
-    readonly_fields = ('datetime', 'timestamp', 'truncated_checksum', 'metadata', 'ready')
+    fields = ('active', 'datetime', 'timestamp', 'truncated_checksum', 'metadata', 'elements', 'ready')
+    readonly_fields = ('datetime', 'timestamp', 'truncated_checksum', 'metadata', 'elements', 'ready')
     extra = 0
     max_num = 0  # Don't allowing adding new versions by hand
     suit_classes = 'suit-tab suit-tab-versions'
