@@ -16,7 +16,7 @@ from django.template.defaultfilters import slugify, truncatechars
 
 import fiona
 from imagekit.models import ImageSpecField
-from imagekit.processors import ResizeToCover, ResizeToFill, ResizeToFit
+from imagekit.processors import ResizeToCover, ResizeToFit
 from model_utils.managers import InheritanceManager
 from picklefield.fields import PickledObjectField
 from pyproj import Proj, transform
@@ -30,17 +30,21 @@ from origins.models import Origin
 
 from .exceptions import LIBREAPIError
 from .job_processing import Job
-from .literals import (DEFAULT_LIMIT, DEFAULT_SHEET, DATA_TYPE_CHOICES,
-    RENDERER_BROWSEABLE_API, RENDERER_JSON, RENDERER_XML, RENDERER_YAML, RENDERER_LEAFLET)
+from .literals import (
+    DEFAULT_LIMIT, DEFAULT_SHEET, DATA_TYPE_CHOICES,
+    RENDERER_BROWSEABLE_API, RENDERER_JSON, RENDERER_XML, RENDERER_YAML,
+    RENDERER_LEAFLET, RENDERER_DATAGRID)
 from .managers import SourceAccessManager
 from .query import Query
 from .utils import DATA_TYPE_FUNCTIONS
 
 logger = logging.getLogger(__name__)
 
+
 class Source(models.Model):
     source_type = _('Base source class')
-    renderers = (RENDERER_JSON, RENDERER_BROWSEABLE_API, RENDERER_XML, RENDERER_YAML)
+    renderers = (RENDERER_JSON, RENDERER_BROWSEABLE_API, RENDERER_XML, RENDERER_YAML, RENDERER_DATAGRID)
+    preview_renderer = RENDERER_DATAGRID
     support_column_regex = False
 
     # Base data
@@ -140,6 +144,7 @@ class Source(models.Model):
 
         source_data_version.ready = True
         source_data_version.active = True
+        source_data_version.elements = row_count
         source_data_version.save()
 
         self.origin_subclass_instance.discard_copy()
@@ -282,7 +287,7 @@ class SourceCSV(Source):
 
         logger.debug('column_names: %s' % column_names)
 
-        for row_dict in DictReader(self.origin_subclass_instance.copy_file, encoding=self.encoding, errors='replace', fieldnames=column_names, **kwargs):
+        for row_dict in DictReader(self.origin_subclass_instance.data_iterator, encoding=self.encoding, errors='replace', fieldnames=column_names, **kwargs):
             if self.process_regex(row_dict):
                 fields = {}
                 for field in self.columns.filter(import_column=True):
@@ -307,7 +312,7 @@ class SourceFixedWidth(Source):
 
         functions_map = self.get_functions_map()
 
-        for row_id, row in enumerate(self.origin_subclass_instance.copy_file, 1):
+        for row_id, row in enumerate(self.origin_subclass_instance.data_iterator, 1):
             try:
                 row_dict = dict(zip(column_names, parse(row)))
             except struct.error as exception:
@@ -366,7 +371,7 @@ class SourceSpreadsheet(Source):
     def _get_rows(self):
         logger.debug('opening workbook')
 
-        self._book = xlrd.open_workbook(file_contents=self.origin_subclass_instance.copy_file.read())
+        self._book = xlrd.open_workbook(file_contents=self.origin_subclass_instance.data_iterator.read())
 
         logger.debug('opening sheet: %s' % self.sheet)
 
@@ -418,7 +423,8 @@ class LeafletMarker(models.Model):
 
 class SourceShape(Source):
     source_type = _('Shapefile')
-    renderers = (RENDERER_JSON, RENDERER_BROWSEABLE_API, RENDERER_XML, RENDERER_YAML, RENDERER_LEAFLET)
+    renderers = (RENDERER_JSON, RENDERER_BROWSEABLE_API, RENDERER_XML, RENDERER_YAML, RENDERER_LEAFLET, RENDERER_DATAGRID)
+    preview_renderer = RENDERER_LEAFLET
     support_column_regex = True
 
     popup_template = models.TextField(blank=True, verbose_name=_('popup template'), help_text=_('Template for rendering the features when displaying them on a map.'))
@@ -455,7 +461,7 @@ class SourceShape(Source):
         logger.debug('geometry_type: %s' % geometry_type)
 
         if geometry_type == 'Point':
-            return _transform(old_projection, new_projection, *coordinates)
+            return transform(old_projection, new_projection, *coordinates)
         elif geometry_type == 'LineString':
             result = []
             for x, y in coordinates:
@@ -489,10 +495,10 @@ class SourceShape(Source):
             return geometry['coordinates']
 
     def _get_metadata(self):
-        old_filename = self.origin_subclass_instance.copy_file.name
+        old_filename = self.origin_subclass_instance.data_iterator.name
         self.filename = old_filename + '.zip'
         os.rename(old_filename, self.filename)
-        self.origin_subclass_instance.copy_file.name = self.filename
+        self.origin_subclass_instance.data_iterator.name = self.filename
 
         self.source = fiona.open('', vfs='zip://%s' % self.filename)
         return self.source.meta
@@ -537,7 +543,7 @@ class SourceDirect(Source):
     support_column_regex = False
 
     def _get_rows(self):
-        return self.origin_subclass_instance.copy_file
+        return self.origin_subclass_instance.data_iterator
 
     class Meta:
         verbose_name = _('direct source')
@@ -551,7 +557,7 @@ class SourceSimple(Source):
     def _get_rows(self):
         functions_map = self.get_functions_map()
 
-        for row in self.origin_subclass_instance.copy_file:
+        for row in self.origin_subclass_instance.data_iterator:
             fields = {}
             for field in self.columns.filter(import_column=True):
                 fields[field.new_name] = functions_map[field.name](row.get(field.name, field.default))
@@ -568,7 +574,7 @@ class SourceSimple(Source):
 
 
 class SourceDataVersion(models.Model):
-    renderers = (RENDERER_JSON, RENDERER_BROWSEABLE_API, RENDERER_XML, RENDERER_YAML)
+    renderers = (RENDERER_JSON, RENDERER_BROWSEABLE_API, RENDERER_XML, RENDERER_YAML, RENDERER_DATAGRID)
 
     source = models.ForeignKey(Source, verbose_name=_('source'), related_name='versions')
     datetime = models.DateTimeField(default=lambda: now())
@@ -578,6 +584,7 @@ class SourceDataVersion(models.Model):
     ready = models.BooleanField(default=False, verbose_name=_('ready'))
     active = models.BooleanField(default=False, verbose_name=_('active'))
     metadata = PickledObjectField(blank=True, verbose_name=_('metadata'))
+    elements = models.PositiveIntegerField(default=0, verbose_name=_('elements'))
 
     def save(self, *args, **kwargs):
         self.timestamp = datetime.datetime.strftime(self.datetime, '%Y%m%d%H%M%S%f')
